@@ -76,7 +76,7 @@ from de.setup_project import (
     code_file_version, pev_str, pev_val, project_env_vars)
 
 
-__version__ = '0.2.3'
+__version__ = '0.2.4'
 
 
 # --------------- global constants ------------------------------------------------------------------------------------
@@ -859,8 +859,8 @@ def _check_templates(pdv: PdvType):
 
 
 def _check_types_linting_tests(pdv: PdvType):
-    is_root = pdv_str(pdv, 'project_type') == ROOT_PRJ
     namespace_name = pdv_str(pdv, 'namespace_name')
+    is_portion = namespace_name and pdv_str(pdv, 'project_type') != ROOT_PRJ
     project_path = pdv_str(pdv, 'project_path')
     tests_folder = pdv_str(pdv, 'TESTS_FOLDER')
     excludes = [".buildozer"]
@@ -869,7 +869,7 @@ def _check_types_linting_tests(pdv: PdvType):
     mypy_options = []
     if _debug_or_verbose():
         args.append("-v")
-    if namespace_name and not is_root:
+    if is_portion:
         mypy_options.append("--namespace-packages")
         args.append(namespace_name)
     else:
@@ -886,6 +886,9 @@ def _check_types_linting_tests(pdv: PdvType):
         _cl(61, "anybadge --label=MyPy --value=passed --file=mypy_report/mypy.svg -o")
 
         os.makedirs(".pylint", exist_ok=True)
+        if is_portion and 'CI_PROJECT_ID' in os.environ:
+            # gitlab pylint err: de/__init__.py:1:0: F0010: error while code parsing: Unable to load file de/__init__.py
+            _cl(62, f"echo > {namespace_name}/__init__.py")
         out: List[str] = []
         _cl(62, f"pylint --output-format=text --max-line-length={line_len} {ignore_options} {' '.join(args)}",
             _exit_on_err=False, lines_output=out)   # instead of _exit_on_err, put the pylint option --exit-zero
@@ -898,7 +901,7 @@ def _check_types_linting_tests(pdv: PdvType):
         cae.po(f"   == pylint score: {score}")
 
         if os.path.isdir(tests_folder):
-            _cl(63, f"pytest --cov-report html --cov={not is_root and namespace_name or 'main'} {tests_folder}/")
+            _cl(63, f"pytest --cov-report html --cov={namespace_name if is_portion else 'main'} {tests_folder}/")
             sub_dir = ".pytest_cache"
             cov_db = ".coverage"
 
